﻿using System.ComponentModel;
using System.Windows.Media;

namespace Telerik.Windows.Examples.Chart.MVVM
{
	public class PersonViewModel : INotifyPropertyChanged
	{
		private Person _person;
		public Person Person
		{
			get
			{
				return _person;
			}
			private set
			{
				_person = value;
			}
		}

		private Brush _gradeColor;
		public Brush GradeColor
		{
			get
			{
				return _gradeColor;
			}
			private set
			{
				_gradeColor = value;
			}
		}

		public PersonViewModel(Person person)
		{
			this.Person = person;
			person.PropertyChanged += HandleStudentPropertyChanged;

			this.UpdateGradeColor();
		}

		private void HandleStudentPropertyChanged(object sender, PropertyChangedEventArgs e)
		{
			if (e.PropertyName == "Grade")
				this.UpdateGradeColor();
		}

		private void UpdateGradeColor()
		{
			if (this.Person.Grade < 10)
				this.GradeColor = this.CreateBrush("#FFFF3D40");
			else if (this.Person.Grade < 20)
				this.GradeColor = this.CreateBrush("#FFFD583A");
			else if (this.Person.Grade < 30)
				this.GradeColor = this.CreateBrush("#FFFD8145");
			else if (this.Person.Grade < 40)
				this.GradeColor = this.CreateBrush("#FFFAA03D");
			else if (this.Person.Grade < 50)
				this.GradeColor = this.CreateBrush("#FFFAC741");
			else if (this.Person.Grade < 60)
				this.GradeColor = this.CreateBrush("#FFFCED40");
			else if (this.Person.Grade < 70)
				this.GradeColor = this.CreateBrush("#FFD7FC3C");
			else if (this.Person.Grade < 80)
				this.GradeColor = this.CreateBrush("#FF99F839");
			else if (this.Person.Grade < 90)
				this.GradeColor = this.CreateBrush("#FF46E633");
			else
				this.GradeColor = this.CreateBrush("#FF1CD64D");

			this.OnPropertyChanged("GradeColor");
		}

		public event PropertyChangedEventHandler PropertyChanged;

		protected virtual void OnPropertyChanged(string propertyName)
		{
			if (this.PropertyChanged != null)
				this.PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
		}

		private Brush CreateBrush(string color)
		{
			return new SolidColorBrush(this.GetColorFromHexString(color));
		}

		private Color GetColorFromHexString(string s)
		{
			s = s.Replace("#", string.Empty);

			byte a = System.Convert.ToByte(s.Substring(0, 2), 16);
			byte r = System.Convert.ToByte(s.Substring(2, 2), 16);
			byte g = System.Convert.ToByte(s.Substring(4, 2), 16);
			byte b = System.Convert.ToByte(s.Substring(6, 2), 16);
			return Color.FromArgb(a, r, g, b);
		}
	}
}
